/*
 *  Copyright (c) 2009 Cyrille Berger <cberger@cberger.net>
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation;
 * either version 2, or (at your option) any later version of the License.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * along with this library; see the file COPYING.  If not, write to
 * the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
 * Boston, MA 02110-1301, USA.
 */

#ifndef _QUICK_STATE_HANDLER_H_
#define _QUICK_STATE_HANDLER_H_

#include <QObject>

class QuickStateHandler : public QObject
{
    Q_OBJECT
public:
    QuickStateHandler(const QString& _catId, const QString& _textId, QObject* _obj);
    ~QuickStateHandler();
public Q_SLOTS:
    void activate();
private:
    QString m_catId;
    QString m_textId;
};

#endif
